@@ -68,7 +68,8 @@ class ExcelConverterGui(QMainWindow):
         file_menu = menu_bar.addMenu("&File")
 
         open_file_action = QAction(
-            QIcon(self.script_dir.split('/')[-1] + '/images/folder-open-big.png'), "Open file...", self)
+            QIcon('folder-open-big.png'), "Open file...", self)
+            # QIcon(self.script_dir.split('/')[-1] + '/images/folder-open-big.png'), "Open file...", self)
             # QIcon(os.path.join('excel2json_gui/images', 'folder-open-big.png')), "Open file...", self)
             # QIcon(os.path.join(self.script_dir, '../images/folder-open-big.png')), "Open file...", self)
         open_file_action.setStatusTip("Open file")
@@ -77,7 +78,8 @@ class ExcelConverterGui(QMainWindow):
         file_toolbar.addAction(open_file_action)
 
         # convert_action = QAction(QIcon(os.path.join('excel2json_gui/images', 'convert-big.png')), "Convert Excel to JSON", self)
-        convert_action = QAction(QIcon(self.script_dir.split('/')[-1] + '/images/convert-big.png'), "Convert Excel to JSON", self)
+        convert_action = QAction(QIcon('convert-big.png'), "Convert Excel to JSON", self)
+        # convert_action = QAction(QIcon(self.script_dir.split('/')[-1] + '/images/convert-big.png'), "Convert Excel to JSON", self)
         # convert_action = QAction(QIcon(os.path.join(self.script_dir, '../images/convert-big.png')), "Convert Excel to JSON", self)
         convert_action.setStatusTip("Convert the Excel file")
         convert_action.triggered.connect(self.convert_file)
@@ -85,7 +87,8 @@ class ExcelConverterGui(QMainWindow):
         file_toolbar.addAction(convert_action)
 
         # save_file_action = QAction(QIcon(os.path.join('excel2json_gui/images', 'save-big.png')), "Save", self)
-        save_file_action = QAction(QIcon(self.script_dir.split('/')[-1] + '/images/save-big.png'), "Save", self)
+        save_file_action = QAction(QIcon('save-big.png'), "Save", self)
+        # save_file_action = QAction(QIcon(self.script_dir.split('/')[-1] + '/images/save-big.png'), "Save", self)
         # save_file_action = QAction(QIcon(os.path.join(self.script_dir, '../images/save-big.png')), "Save", self)
         save_file_action.setStatusTip("Save JSON")
         save_file_action.triggered.connect(self.file_save)
@@ -95,7 +98,9 @@ class ExcelConverterGui(QMainWindow):
         self.show()
 
     def get_image_path(self, var):
-        relative_path = f"/images/{type(var).__name__}.png"
+        # relative_path = f"/images/{type(var).__name__}.png"
+        image = f"{type(var).__name__}.png"
+        return image
         # return os.path.join(self.script_dir, relative_path)
         return self.script_dir.split('/')[-1] + relative_path
         # return relative_path
@@ -143,8 +148,8 @@ class ExcelConverterGui(QMainWindow):
         if isinstance(value, dict):
             for key, val in value.items():
                 child = QTreeWidgetItem()
-                # icon = QIcon(os.path.join('excel2json_gui/images', f"{type(val).__name__}.png"))
-                icon = QIcon(self.get_image_path(val))
+                icon = QIcon(os.path.join('excel2json_gui/images', f"{type(val).__name__}.png"))
+                # icon = QIcon(self.get_image_path(val))
                 child.setIcon(0, icon)
                 if any(map(lambda x: isinstance(val, x), (str, bool, int))):
                     child.setText(0, f'{key}: "{val}"' if isinstance(val, str) else f'{key}: {val}')
@@ -157,8 +162,8 @@ class ExcelConverterGui(QMainWindow):
             for idx, val in enumerate(value):
                 child = QTreeWidgetItem()
                 item.addChild(child)
-                # icon = QIcon(os.path.join('excel2json_gui/images', f"{type(val).__name__}.png"))
-                icon = QIcon(self.get_image_path(val))
+                icon = QIcon(os.path.join('excel2json_gui/images', f"{type(val).__name__}.png"))
+                # icon = QIcon(self.get_image_path(val))
                 child.setIcon(0, icon)
                 if isinstance(val, dict):
                     child.setText(0, f'{idx}')
@@ -171,8 +176,8 @@ class ExcelConverterGui(QMainWindow):
         else:
             child = QTreeWidgetItem()
             child.setText(0, f"{value}")
-            # icon = QIcon(os.path.join('excel2json_gui/images', f"{type(value).__name__}.png"))
-            icon = QIcon(self.get_image_path(value))
+            icon = QIcon(os.path.join('excel2json_gui/images', f"{type(value).__name__}.png"))
+            # icon = QIcon(self.get_image_path(value))
             child.setIcon(0, icon)
             item.addChild(child)
 
